@@ -8,6 +8,12 @@ use std::{
     },
 };
 
+use cosmian_crypto_base::{
+    hybrid_crypto::Metadata,
+    symmetric_crypto::{aes_256_gcm_pure::Aes256GcmCrypto, Key, SymmetricCrypto},
+};
+use lazy_static::lazy_static;
+
 use crate::{
     core::{
         bilinear_map::bls12_381::Bls12_381,
@@ -26,12 +32,6 @@ use crate::{
         },
     },
 };
-use cosmian_crypto_base::symmetric_crypto::Key;
-use cosmian_crypto_base::{
-    hybrid_crypto::Metadata,
-    symmetric_crypto::{aes_256_gcm_pure::Aes256GcmCrypto, SymmetricCrypto},
-};
-use lazy_static::lazy_static;
 
 type PublicKey = <Gpsw<Bls12_381> as AbeScheme>::MasterPublicKey;
 type UserDecryptionKey = <Gpsw<Bls12_381> as AbeScheme>::UserDecryptionKey;
@@ -559,11 +559,34 @@ pub unsafe extern "C" fn h_aes_decrypt_header_using_cache(
     0
 }
 
+#[no_mangle]
+/// # Safety
+pub unsafe extern "C" fn h_get_encrypted_header_size(
+    encrypted_ptr: *const c_char,
+    encrypted_len: c_int,
+) -> c_int {
+    ffi_not_null!(encrypted_ptr, "Encrypted bytes pointer should not be bull");
+    //
+    // Check `encrypted_bytes` input param and store it locally
+    if encrypted_len == 0 {
+        ffi_bail!("Encrypted value must be at least 4-bytes long");
+    }
+    let encrypted_header_bytes =
+        std::slice::from_raw_parts(encrypted_ptr as *const u8, encrypted_len as usize);
+
+    //
+    // Recover header from `encrypted_bytes`
+    let mut header_size_bytes = [0; 4];
+    header_size_bytes.copy_from_slice(&encrypted_header_bytes.to_vec()[0..4]);
+    i32::from_be_bytes(header_size_bytes)
+}
+
 #[no_mangle]
 /// Decrypt an encrypted header returning the symmetric key,
 /// the uid and additional data if available.
 ///
-/// Slower tha using a cache but avoids handling the cache creation and destruction.
+/// Slower tha using a cache but avoids handling the cache creation and
+/// destruction.
 ///
 /// No additional data will be returned if the `additional_data_ptr` is NULL.
 ///
@@ -670,7 +693,8 @@ pub unsafe extern "C" fn h_aes_decrypt_header(
     0
 }
 
-// maximum clear text size that can be safely encrypted with AES GCM (using a a single random nonce)
+// maximum clear text size that can be safely encrypted with AES GCM (using a a
+// single random nonce)
 pub const MAX_CLEAR_TEXT_SIZE: usize = 1_usize << 30;
 
 #[no_mangle]
