@@ -2,4 +2,6 @@ pub mod asymmetric_crypto;
 #[cfg(feature = "ffi")]
 pub mod ffi;
 pub mod hybrid_crypto;
+#[cfg(feature = "wasm_bindgen")]
+pub mod wasm_bindgen;
 pub use crate::core::policy;
